@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,15 +56,16 @@ import com.openexchange.conversion.servlet.ConversionServlet;
 import com.openexchange.conversion.servlet.ConversionServletServiceRegistry;
 import com.openexchange.server.osgiservice.DeferredActivator;
 import com.openexchange.server.osgiservice.ServiceRegistry;
+import com.openexchange.tools.service.SessionServletRegistration;
 
 /**
  * {@link ConversionServletActivator}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ConversionServletActivator extends DeferredActivator {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ConversionServletActivator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ConversionServletActivator.class));
 
     private static final String ALIAS = "ajax/conversion";
 
@@ -77,7 +78,9 @@ public final class ConversionServletActivator extends DeferredActivator {
         super();
     }
 
-    private static final Class<?>[] NEEDED_SERVICES = { HttpService.class, ConversionService.class };
+    private static final Class<?>[] NEEDED_SERVICES = { ConversionService.class };
+
+    private SessionServletRegistration servletRegistration;
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -90,22 +93,13 @@ public final class ConversionServletActivator extends DeferredActivator {
         if (!allAvailable()) {
             return;
         }
-        final HttpService httpService = getService(HttpService.class);
-        try {
-            httpService.registerServlet(ALIAS, (conversionServlet = new ConversionServlet()), null, null);
-            LOG.info(ConversionServlet.class.getName() + " successfully re-registered due to re-appearing of " + clazz.getName());
-        } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
-        }
     }
 
     @Override
     protected void handleUnavailability(final Class<?> clazz) {
-        final HttpService httpService = getService(HttpService.class);
-        if (httpService != null && conversionServlet != null) {
-            httpService.unregister(ALIAS);
-            conversionServlet = null;
-            LOG.info(ConversionServlet.class.getName() + " unregistered due to disappearing of " + clazz.getName());
+        if(servletRegistration != null) {
+            servletRegistration.close();
+            servletRegistration = null;
         }
         ConversionServletServiceRegistry.getServiceRegistry().removeService(clazz);
     }
@@ -120,19 +114,15 @@ public final class ConversionServletActivator extends DeferredActivator {
                 final ServiceRegistry registry = ConversionServletServiceRegistry.getServiceRegistry();
                 registry.clearRegistry();
                 final Class<?>[] classes = getNeededServices();
-                for (int i = 0; i < classes.length; i++) {
-                    final Object service = getService(classes[i]);
+                for (final Class<?> classe : classes) {
+                    final Object service = getService(classe);
                     if (null != service) {
-                        registry.addService(classes[i], service);
+                        registry.addService(classe, service);
                     }
                 }
             }
-            /*
-             * Http service is available: Register servlet
-             */
-            final HttpService httpService = getService(HttpService.class);
-            httpService.registerServlet(ALIAS, (conversionServlet = new ConversionServlet()), null, null);
-            LOG.info(ConversionServlet.class.getName() + " successfully registered");
+            servletRegistration = new SessionServletRegistration(context, new ConversionServlet(), ALIAS);
+            servletRegistration.open();
         } catch (final Exception e) {
             LOG.error(e.getMessage(), e);
             throw e;
